==> vradi-entities-0.0.4-sources.jar: com/jurismarches/vradi/entities/FormBean.java <==
package com.jurismarches.vradi.entities;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.Date;
import java.util.Set;
import org.sharengo.wikitty.BusinessEntityBean;

public class FormBean extends com.jurismarches.vradi.entities.InfogeneBean implements Form, Infogene {

    private static final long serialVersionUID = -49743860L;

    public FormBean() {
        super();
    }

     protected PropertyChangeSupport propertyChange = new PropertyChangeSupport(this);

    public void addPropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(listener);
	}

	public void removePropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(listener);
	}

	public void addPropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(propertyName, listener);
	}

	public void removePropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(propertyName, listener);
	}

    public Date Form$datePub;

     public Date Form$datePeremption;

     public Set<String> Form$thesaurus;

     public Set<String> Form$sending;

 
    public void setDatePub(Date value) {
        Object oldValue = Form$datePub; 
        this.Form$datePub = value;
        propertyChange.firePropertyChange("datePub", oldValue, value);
    }

    public Date getDatePub() {
        return Form$datePub;
    }


    public void setDatePeremption(Date value) {
        Object oldValue = Form$datePeremption; 
        this.Form$datePeremption = value;
        propertyChange.firePropertyChange("datePeremption", oldValue, value);
    }

    public Date getDatePeremption() {
        return Form$datePeremption;
    }

    public Set<String> getThesaurus() {
        return Form$thesaurus;
    }

    public void addThesaurus(String element) {
        Form$thesaurus.add(element);
        propertyChange.firePropertyChange("thesaurus", null, Form$thesaurus);
    }
    
    public void removeThesaurus(String element) {
        Form$thesaurus.remove(element);
        propertyChange.firePropertyChange("thesaurus", null, Form$thesaurus);
    }
    
    public void clearThesaurus() {
        Form$thesaurus.clear();
        propertyChange.firePropertyChange("thesaurus", null, Form$thesaurus);
    }

    public Set<String> getSending() {
        return Form$sending;
    }

    public void addSending(String element) {
        Form$sending.add(element);
        propertyChange.firePropertyChange("sending", null, Form$sending);
    }
    
    public void removeSending(String element) {
        Form$sending.remove(element);
        propertyChange.firePropertyChange("sending", null, Form$sending);
    }
    
    public void clearSending() {
        Form$sending.clear();
        propertyChange.firePropertyChange("sending", null, Form$sending);
    }

    public String Infogene$id;

     public String Infogene$objet;

     public Date Infogene$creationDate;

     public String Infogene$sourceURL;

     public String Infogene$sourceText;

     public String Infogene$entity;

     public String Infogene$country;

     public String Infogene$department;

     public String Infogene$description;

     public String Infogene$status;

 
    public void setId(String value) {
        Object oldValue = Infogene$id; 
        this.Infogene$id = value;
        propertyChange.firePropertyChange("id", oldValue, value);
    }

    public String getId() {
        return Infogene$id;
    }


    public void setObjet(String value) {
        Object oldValue = Infogene$objet; 
        this.Infogene$objet = value;
        propertyChange.firePropertyChange("objet", oldValue, value);
    }

    public String getObjet() {
        return Infogene$objet;
    }


    public void setCreationDate(Date value) {
        Object oldValue = Infogene$creationDate; 
        this.Infogene$creationDate = value;
        propertyChange.firePropertyChange("creationDate", oldValue, value);
    }

    public Date getCreationDate() {
        return Infogene$creationDate;
    }


    public void setSourceURL(String value) {
        Object oldValue = Infogene$sourceURL; 
        this.Infogene$sourceURL = value;
        propertyChange.firePropertyChange("sourceURL", oldValue, value);
    }

    public String getSourceURL() {
        return Infogene$sourceURL;
    }


    public void setSourceText(String value) {
        Object oldValue = Infogene$sourceText; 
        this.Infogene$sourceText = value;
        propertyChange.firePropertyChange("sourceText", oldValue, value);
    }

    public String getSourceText() {
        return Infogene$sourceText;
    }


    public void setEntity(String value) {
        Object oldValue = Infogene$entity; 
        this.Infogene$entity = value;
        propertyChange.firePropertyChange("entity", oldValue, value);
    }

    public String getEntity() {
        return Infogene$entity;
    }


    public void setCountry(String value) {
        Object oldValue = Infogene$country; 
        this.Infogene$country = value;
        propertyChange.firePropertyChange("country", oldValue, value);
    }

    public String getCountry() {
        return Infogene$country;
    }


    public void setDepartment(String value) {
        Object oldValue = Infogene$department; 
        this.Infogene$department = value;
        propertyChange.firePropertyChange("department", oldValue, value);
    }

    public String getDepartment() {
        return Infogene$department;
    }


    public void setDescription(String value) {
        Object oldValue = Infogene$description; 
        this.Infogene$description = value;
        propertyChange.firePropertyChange("description", oldValue, value);
    }

    public String getDescription() {
        return Infogene$description;
    }


    public void setStatus(String value) {
        Object oldValue = Infogene$status; 
        this.Infogene$status = value;
        propertyChange.firePropertyChange("status", oldValue, value);
    }

    public String getStatus() {
        return Infogene$status;
    }


} //FormBean

==> vradi-entities-0.0.5-sources.jar: com/jurismarches/vradi/entities/FormBean.java <==
package com.jurismarches.vradi.entities;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.Date;
import java.util.Set;
import org.sharengo.wikitty.BusinessEntityBean;

public class FormBean extends com.jurismarches.vradi.entities.InfogeneBean implements Form, Infogene {

    private static final long serialVersionUID = -63690911L;

    public FormBean() {
        super();
    }

    protected transient PropertyChangeSupport propertyChange = new PropertyChangeSupport(this);

    public void addPropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(listener);
	}

	public void removePropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(listener);
	}

	public void addPropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(propertyName, listener);
	}

	public void removePropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(propertyName, listener);
	}

    public Date Form$datePub;

    public Date Form$datePeremption;

    public Set<String> Form$thesaurus;

    public Set<String> Form$files;

    public Set<String> Form$attachments;

    public String Form$xmlStreamURL;


    public void setDatePub(Date value) {
        Object oldValue = Form$datePub; 
        this.Form$datePub = value;
        propertyChange.firePropertyChange("datePub", oldValue, value);
    }

    public Date getDatePub() {
        return Form$datePub;
    }


    public void setDatePeremption(Date value) {
        Object oldValue = Form$datePeremption; 
        this.Form$datePeremption = value;
        propertyChange.firePropertyChange("datePeremption", oldValue, value);
    }

    public Date getDatePeremption() {
        return Form$datePeremption;
    }

    public Set<String> getThesaurus() {
        return Form$thesaurus;
    }

    public void addThesaurus(String element) {
        Form$thesaurus.add(element);
        propertyChange.firePropertyChange("thesaurus", null, Form$thesaurus);
    }
    
    public void removeThesaurus(String element) {
        Form$thesaurus.remove(element);
        propertyChange.firePropertyChange("thesaurus", null, Form$thesaurus);
    }
    
    public void clearThesaurus() {
        Form$thesaurus.clear();
        propertyChange.firePropertyChange("thesaurus", null, Form$thesaurus);
    }

    public Set<String> getFiles() {
        return Form$files;
    }

    public void addFiles(String element) {
        Form$files.add(element);
        propertyChange.firePropertyChange("files", null, Form$files);
    }
    
    public void removeFiles(String element) {
        Form$files.remove(element);
        propertyChange.firePropertyChange("files", null, Form$files);
    }
    
    public void clearFiles() {
        Form$files.clear();
        propertyChange.firePropertyChange("files", null, Form$files);
    }

    public Set<String> getAttachments() {
        return Form$attachments;
    }

    public void addAttachments(String element) {
        Form$attachments.add(element);
        propertyChange.firePropertyChange("attachments", null, Form$attachments);
    }
    
    public void removeAttachments(String element) {
        Form$attachments.remove(element);
        propertyChange.firePropertyChange("attachments", null, Form$attachments);
    }
    
    public void clearAttachments() {
        Form$attachments.clear();
        propertyChange.firePropertyChange("attachments", null, Form$attachments);
    }


    public void setXmlStreamURL(String value) {
        Object oldValue = Form$xmlStreamURL; 
        this.Form$xmlStreamURL = value;
        propertyChange.firePropertyChange("xmlStreamURL", oldValue, value);
    }

    public String getXmlStreamURL() {
        return Form$xmlStreamURL;
    }

    public String Infogene$id;

    public String Infogene$objet;

    public Date Infogene$creationDate;

    public String Infogene$sourceURL;

    public String Infogene$sourceText;

    public String Infogene$entity;

    public String Infogene$country;

    public String Infogene$department;

    public String Infogene$description;

    public Set<String> Infogene$tag;

    public String Infogene$status;


    public void setId(String value) {
        Object oldValue = Infogene$id; 
        this.Infogene$id = value;
        propertyChange.firePropertyChange("id", oldValue, value);
    }

    public String getId() {
        return Infogene$id;
    }


    public void setObjet(String value) {
        Object oldValue = Infogene$objet; 
        this.Infogene$objet = value;
        propertyChange.firePropertyChange("objet", oldValue, value);
    }

    public String getObjet() {
        return Infogene$objet;
    }


    public void setCreationDate(Date value) {
        Object oldValue = Infogene$creationDate; 
        this.Infogene$creationDate = value;
        propertyChange.firePropertyChange("creationDate", oldValue, value);
    }

    public Date getCreationDate() {
        return Infogene$creationDate;
    }


    public void setSourceURL(String value) {
        Object oldValue = Infogene$sourceURL; 
        this.Infogene$sourceURL = value;
        propertyChange.firePropertyChange("sourceURL", oldValue, value);
    }

    public String getSourceURL() {
        return Infogene$sourceURL;
    }


    public void setSourceText(String value) {
        Object oldValue = Infogene$sourceText; 
        this.Infogene$sourceText = value;
        propertyChange.firePropertyChange("sourceText", oldValue, value);
    }

    public String getSourceText() {
        return Infogene$sourceText;
    }


    public void setEntity(String value) {
        Object oldValue = Infogene$entity; 
        this.Infogene$entity = value;
        propertyChange.firePropertyChange("entity", oldValue, value);
    }

    public String getEntity() {
        return Infogene$entity;
    }


    public void setCountry(String value) {
        Object oldValue = Infogene$country; 
        this.Infogene$country = value;
        propertyChange.firePropertyChange("country", oldValue, value);
    }

    public String getCountry() {
        return Infogene$country;
    }


    public void setDepartment(String value) {
        Object oldValue = Infogene$department; 
        this.Infogene$department = value;
        propertyChange.firePropertyChange("department", oldValue, value);
    }

    public String getDepartment() {
        return Infogene$department;
    }


    public void setDescription(String value) {
        Object oldValue = Infogene$description; 
        this.Infogene$description = value;
        propertyChange.firePropertyChange("description", oldValue, value);
    }

    public String getDescription() {
        return Infogene$description;
    }

    public Set<String> getTag() {
        return Infogene$tag;
    }

    public void addTag(String element) {
        Infogene$tag.add(element);
        propertyChange.firePropertyChange("tag", null, Infogene$tag);
    }
    
    public void removeTag(String element) {
        Infogene$tag.remove(element);
        propertyChange.firePropertyChange("tag", null, Infogene$tag);
    }
    
    public void clearTag() {
        Infogene$tag.clear();
        propertyChange.firePropertyChange("tag", null, Infogene$tag);
    }


    public void setStatus(String value) {
        Object oldValue = Infogene$status; 
        this.Infogene$status = value;
        propertyChange.firePropertyChange("status", oldValue, value);
    }

    public String getStatus() {
        return Infogene$status;
    }


} //FormBean
